SET storage_engine = InnoDB;
SET FOREIGN_KEY_CHECKS = 1;
DROP DATABASE IF EXISTS delivery;
CREATE DATABASE delivery;
USE delivery;

CREATE TABLE Deliverers (
	DelivererID  SMALLINT NOT NULL,
	Name CHAR(15) NOT NULL,
	Initials CHAR(3),
	Year_Of_Birth SMALLINT,
	Sex CHAR(1),
	Year_Joined SMALLINT NOT NULL,
	Street CHAR(15) NOT NULL,
	HouseNo CHAR(4),
	PostCode CHAR(6),
	Town CHAR(10) NOT NULL,
	CellNo CHAR(10),
	PhoneNo CHAR(4),
	PRIMARY KEY (DelivererID)
 );

CREATE TABLE Companies (
	CompanyID SMALLINT NOT NULL,
	DelivererID SMALLINT NOT NULL,
	Mandate CHAR(6) NOT NULL,
	PRIMARY KEY(CompanyID),
	FOREIGN KEY(DelivererID) REFERENCES Deliverers(DelivererID)
);

CREATE TABLE CompanyDel (
	CompanyID SMALLINT NOT NULL ,
	DelivererID SMALLINT NOT NULL,
	NumDeliveries SMALLINT NOT NULL,
	NumCollections SMALLINT NOT NULL,
	PRIMARY KEY (CompanyID, DelivererID),
	FOREIGN KEY(DelivererID)
		REFERENCES Deliverers(DelivererID)
		ON DELETE CASCADE
		ON UPDATE CASCADE,
	FOREIGN KEY(CompanyID)
		REFERENCES Companies(CompanyID)
		ON DELETE CASCADE
		ON UPDATE CASCADE
);

CREATE TABLE Penalties (
	PaymentID INTEGER NOT NULL,
	DelivererID SMALLINT NOT NULL,
	Data DATE NOT NULL,
	Amount DECIMAL(7, 2) NOT NULL,
	PRIMARY KEY(PaymentID),
	FOREIGN KEY(DelivererID)
		REFERENCES Deliverers(DelivererID)
		ON DELETE CASCADE
		ON UPDATE CASCADE
	);

INSERT INTO Deliverers
	VALUES (2, 'Everett', 'R', 1948, 'M', 1975, 'Stoney Road', '43', '3575NH', 'Stratford', '070-237893', '2411');

INSERT INTO Deliverers
	VALUES (6, 'Parmenter', 'R', 1964, 'M', 1977, 'Haseltine Lane', '80', '1234KK', 'Stratford', '070-476537', '8467');

INSERT INTO Deliverers
	VALUES (8, 'Newcastle', 'B', 1962, 'F', 1980, 'Station Road', '4', '6584WO', 'Inglewood', '070-476573', '2983');

INSERT INTO Deliverers
	VALUES (27, 'Collins', 'DD', 1964, 'F', 1983, 'Long Drive', '804', '8457DK', 'Eltham', '079-234857', '2513');

INSERT INTO Deliverers
	VALUES (44, 'Baker', 'E', 1963, 'M', 1980, 'Lewis Street', '23', '4444LJ', 'Inglewood', '070-368753', '1124');

INSERT INTO Deliverers
	VALUES (57, 'Brown', 'M', 1971, 'M', 1985, 'Edgecombe Way', '16', '4377CB', 'Stratford', '070-473458', '6409');

INSERT INTO Deliverers
	VALUES (83, 'Hope', 'PK', 1956, 'M', 1982, 'Magdalene Road', '16a', '1812UP', 'Stratford', '070-353548', '1608');

INSERT INTO Deliverers
	VALUES (100, 'Parmenter', 'P', 1963, 'M', 1979, 'Haseltine Lane', '80', '1234KK', 'Stratford', '070-476537', '6524');

INSERT INTO Deliverers
	VALUES (104, 'Moorman', 'D', 1970, 'F', 1984, 'Stout Street', '65', '9437AO', 'Eltham', '079-987571', '7060');

INSERT INTO Deliverers
	VALUES (112, 'Bailey', 'IP', 1963, 'F', 1984, 'Vixen Road', '8', '6392LK', 'Plymouth', '010-54874', '1319');

INSERT INTO Deliverers
	VALUES (7, 'Wise', 'GWS', 1963, 'M', 1981, 'Edgecombe Way', '39', '9758VB', 'Stratford', '070-347689', NULL);

INSERT INTO Deliverers
	VALUES (28, 'Collins', 'C', 1963, 'F', 1983, 'Old Main Road', '10', '1294QK', 'Midhurst', '010-659599', NULL);

INSERT INTO Deliverers
	VALUES (39, 'Bishop', 'D', 1956, 'M', 1980, 'Eaton Square', '78', '9629CD', 'Stratford', '070-393435', NULL);

INSERT INTO Deliverers
	VALUES (95, 'Miller', 'P', 1934, 'M', 1972, 'High Street', '33a', '5746OP', 'Douglas', '070-867564', NULL);

INSERT INTO Companies
	VALUES (1, 6, 'first');

INSERT INTO Companies
	VALUES ( 2, 27, 'second');

INSERT INTO CompanyDel
	VALUES (1, 2, 4, 8);

INSERT INTO CompanyDel
	VALUES (1, 6, 9, 1);

INSERT INTO CompanyDel
	VALUES (1, 8, 0, 1);

INSERT INTO CompanyDel
	VALUES (1, 44, 7, 5);

INSERT INTO CompanyDel
	VALUES (1, 57, 5, 0);

INSERT INTO CompanyDel
	VALUES (1, 83, 3, 3);

INSERT INTO CompanyDel
	VALUES (2, 8, 4, 4);

INSERT INTO CompanyDel
	VALUES (2, 27, 11, 2);
	   
INSERT INTO CompanyDel
	VALUES (2, 104, 8, 4);
	   
INSERT INTO CompanyDel
	VALUES (2, 112, 4, 8);

INSERT INTO Penalties 
	VALUES (1, 6, '1980/12/08', 100);
	   
INSERT INTO Penalties 
	VALUES (2, 44, '1981/05/05', 75);
	   
INSERT INTO Penalties 
	VALUES (3, 27, '1983/09/10', 100);
	   
INSERT INTO Penalties 
	VALUES (4, 104, '1984/12/08', 50);
	   
INSERT INTO Penalties 
	VALUES (5, 44, '1980/12/08', 25);
	   
INSERT INTO Penalties 
	VALUES (6, 8, '1980/12/08', 25);
	   
INSERT INTO Penalties 
	VALUES (7, 44, '1982/12/30', 30);
	   
INSERT INTO Penalties 
	VALUES (8, 27, '1984/11/12', 75);
	   